autowisp.database.data_model.provenance.camera_channel module — AutoWISP documentation

# autowisp.database.data_model.provenance.camera_channel module

## Class Inheritance Diagram

Define the camera color channel table for the pipeline

class autowisp.database.data_model.provenance.camera_channel.CameraChannel(**kwargs)

  Bases: `DataModelBase`

  The table describing each of the channels of a type of camera.

  camera_type_id

    The camera type to which this channel belongs.

  id

    A unique identifier for each row.

  name

    A label to assign to the channel.

  timestamp

    When record was last changed

  x_offset

    The x index of the first pixel of the channel.

  x_step

    The step in the x direction between consecutive pixels of the channel.

  y_offset

    The y index of the first pixel of the channel.

  y_step

    The step in the y direction between consecutive pixels of the channel.